"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const baseMetadataTransformer_1 = require("./baseMetadataTransformer");
const convertTransaction_1 = require("../convertTransaction");
const metadata_registry_1 = require("../../metadata-registry");
const constants_1 = require("../../utils/constants");
const streams_1 = require("../streams");
const path_1 = require("path");
class DecomposedMetadataTransformer extends baseMetadataTransformer_1.BaseMetadataTransformer {
    constructor(registry = metadata_registry_1.registryData, convertTransaction = new convertTransaction_1.ConvertTransaction()) {
        super(registry, convertTransaction);
        this.convertTransaction.addFinalizer(convertTransaction_1.RecompositionFinalizer);
    }
    toMetadataFormat(component) {
        return __awaiter(this, void 0, void 0, function* () {
            if (component.parent) {
                const { state } = this.convertTransaction;
                const { fullName: parentName } = component.parent;
                if (!state.recompose[parentName]) {
                    state.recompose[parentName] = {
                        component: component.parent,
                        children: [],
                    };
                }
                state.recompose[parentName].children.push(component);
                // noop since the finalizer will push the writes to the component writer
                return { component: component, writeInfos: [] };
            }
            const recomposedXmlObj = yield DecomposedMetadataTransformer.recompose(component.getChildren(), (yield component.parseXml()));
            return DecomposedMetadataTransformer.createWriterFormat(component, recomposedXmlObj);
        });
    }
    toSourceFormat(component) {
        var _a, _b;
        return __awaiter(this, void 0, void 0, function* () {
            const writeInfos = [];
            const { type, fullName: parentFullName } = component;
            const rootPackagePath = component.getPackageRelativePath(parentFullName, 'source');
            const composedMetadata = (yield component.parseXml())[type.name];
            const rootXmlObject = { [type.name]: {} };
            for (const [tagName, collection] of Object.entries(composedMetadata)) {
                const childTypeId = (_b = (_a = type) === null || _a === void 0 ? void 0 : _a.children) === null || _b === void 0 ? void 0 : _b.directories[tagName];
                if (childTypeId) {
                    const childType = type.children.types[childTypeId];
                    const tagCollection = Array.isArray(collection) ? collection : [collection];
                    for (const entry of tagCollection) {
                        let relativeDestination = rootPackagePath;
                        const strategy = this.registry.strategies[type.id].decomposition;
                        if (strategy === "folderPerType" /* FolderPerType */) {
                            relativeDestination = path_1.join(relativeDestination, childType.directoryName);
                        }
                        const name = (entry.fullName || entry.name);
                        relativeDestination = path_1.join(relativeDestination, `${name}.${childType.suffix}${constants_1.META_XML_SUFFIX}`);
                        writeInfos.push({
                            source: new streams_1.JsToXml({
                                [childType.name]: Object.assign({ [constants_1.XML_NS_KEY]: constants_1.XML_NS }, entry),
                            }),
                            relativeDestination,
                        });
                    }
                }
                else {
                    rootXmlObject[type.name][tagName] = collection;
                }
            }
            writeInfos.push({
                source: new streams_1.JsToXml(rootXmlObject),
                relativeDestination: path_1.join(rootPackagePath, `${parentFullName}.${type.suffix}${constants_1.META_XML_SUFFIX}`),
            });
            return { component, writeInfos };
        });
    }
    static recompose(children, baseXmlObj = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            for (const child of children) {
                const { directoryName: groupNode } = child.type;
                const { name: parentName } = child.parent.type;
                const childContents = (yield child.parseXml())[child.type.name];
                if (!baseXmlObj[parentName]) {
                    baseXmlObj[parentName] = { '@_xmlns': constants_1.XML_NS };
                }
                if (!baseXmlObj[parentName][groupNode]) {
                    baseXmlObj[parentName][groupNode] = [];
                }
                baseXmlObj[parentName][groupNode].push(childContents);
            }
            return baseXmlObj;
        });
    }
    static createWriterFormat(trigger, xmlObject) {
        return {
            component: trigger,
            writeInfos: [
                {
                    source: new streams_1.JsToXml(xmlObject),
                    relativeDestination: path_1.join(trigger.type.directoryName, `${trigger.fullName}.${trigger.type.suffix}`),
                },
            ],
        };
    }
}
exports.DecomposedMetadataTransformer = DecomposedMetadataTransformer;
//# sourceMappingURL=decomposedMetadataTransformer.js.map