"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
const utils_1 = require("../../utils");
const fs_1 = require("fs");
const baseMetadataTransformer_1 = require("./baseMetadataTransformer");
/**
 * The default metadata transformer.
 *
 * If a metadata type doesn't have a transformer assigned to it, this one is used
 * during the conversion process. It leaves the component's metadata xml and source
 * files as-is.
 */
class DefaultMetadataTransformer extends baseMetadataTransformer_1.BaseMetadataTransformer {
    toMetadataFormat(component) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.getWriterFormat(component, 'metadata');
        });
    }
    toSourceFormat(component) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.getWriterFormat(component, 'source');
        });
    }
    getWriterFormat(component, toFormat) {
        const result = { component: component, writeInfos: [] };
        if (component.content) {
            for (const source of component.walkContent()) {
                result.writeInfos.push({
                    source: fs_1.createReadStream(source),
                    relativeDestination: component.getPackageRelativePath(source, toFormat),
                });
            }
        }
        if (component.xml) {
            let xmlDest = component.getPackageRelativePath(component.xml, toFormat);
            if (!component.content) {
                xmlDest =
                    toFormat === 'metadata'
                        ? xmlDest.slice(0, xmlDest.lastIndexOf(utils_1.META_XML_SUFFIX))
                        : `${xmlDest}${utils_1.META_XML_SUFFIX}`;
            }
            result.writeInfos.push({
                source: fs_1.createReadStream(component.xml),
                relativeDestination: xmlDest,
            });
        }
        return result;
    }
}
exports.DefaultMetadataTransformer = DefaultMetadataTransformer;
//# sourceMappingURL=defaultMetadataTransformer.js.map