"use strict";
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
/**
 * Returns the `MetadataXml` info from a given file path. If the path is not a
 * metadata xml file (-meta.xml), returns `undefined`
 *
 * @param path
 */
exports.parseMetadataXml = (path) => {
    const match = path_1.basename(path).match(/(.+)\.(.+)-meta\.xml/);
    if (match) {
        return { fullName: match[1], suffix: match[2], path: path };
    }
};
/**
 * Deeply freezes an object, making the entire thing immutable.
 * @param object Object to deep freeze
 */
exports.deepFreeze = (object) => {
    const propNames = Object.getOwnPropertyNames(object);
    for (const name of propNames) {
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        const val = object[name];
        if (val && typeof val === 'object') {
            exports.deepFreeze(val);
        }
    }
    return Object.freeze(object);
};
//# sourceMappingURL=registry.js.map