"use strict";
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@salesforce/core");
const testSetup_1 = require("@salesforce/core/lib/testSetup");
const chai_1 = require("chai");
const fs = require("fs");
const sinon_1 = require("sinon");
const deployStrategies_1 = require("../../../src/client/deployStrategies");
const i18n_1 = require("../../../src/i18n");
const $$ = testSetup_1.testSetup();
describe('Base Deploy Strategy', () => {
    let simpleMetaXMLString = '<?xml version="1.0" encoding="UTF-8"?>';
    simpleMetaXMLString += '<ApexClass xmlns="http://soap.sforce.com/2006/04/metadata">';
    simpleMetaXMLString += '    <apiVersion>32.0</apiVersion>';
    simpleMetaXMLString += '    <status>Active</status>';
    simpleMetaXMLString += '</ApexClass>';
    const testData = new testSetup_1.MockTestOrgData();
    let mockConnection;
    let sandboxStub;
    beforeEach(() => __awaiter(void 0, void 0, void 0, function* () {
        sandboxStub = sinon_1.createSandbox();
        $$.setConfigStubContents('AuthInfoConfig', {
            contents: yield testData.getConfig(),
        });
        mockConnection = yield core_1.Connection.create({
            authInfo: yield core_1.AuthInfo.create({
                username: testData.username,
            }),
        });
        const mockFS = sandboxStub.stub(fs, 'readFileSync');
        mockFS.withArgs('file/path/one.cls', 'utf8').returns('public with sharing class TestAPI {}');
        mockFS.withArgs('file/path/one.cls-meta.xml', 'utf8').returns(simpleMetaXMLString);
    }));
    afterEach(() => {
        sandboxStub.restore();
    });
    it('should create a metadata field with package versions', () => {
        const deployLibrary = new deployStrategies_1.ContainerDeploy(mockConnection);
        const testMetadataField = {
            apiVersion: '47.0',
            status: 'Active',
            packageVersions: '      1      0      packageA    ',
        };
        let metaXMLString = '<?xml version="1.0" encoding="UTF-8"?>';
        metaXMLString += '<ApexClass xmlns="http://soap.sforce.com/2006/04/metadata">';
        metaXMLString += '    <apiVersion>47.0</apiVersion>';
        metaXMLString += '    <packageVersions>';
        metaXMLString += '      <majorNumber>1</majorNumber>';
        metaXMLString += '      <minorNumber>0</minorNumber>';
        metaXMLString += '      <namespace>packageA</namespace>';
        metaXMLString += '    </packageVersions>';
        metaXMLString += '    <packageVersions>';
        metaXMLString += '      <majorNumber>8</majorNumber>';
        metaXMLString += '      <minorNumber>21</minorNumber>';
        metaXMLString += '      <namespace>packageB</namespace>';
        metaXMLString += '    </packageVersions>';
        metaXMLString += '    <status>Active</status>';
        metaXMLString += '</ApexClass>';
        const metadataField = deployLibrary.buildMetadataField(metaXMLString);
        chai_1.expect(metadataField).to.deep.equals(testMetadataField);
    });
    it('should throw an error for incorrect metadata file', () => {
        const deployLibrary = new deployStrategies_1.ContainerDeploy(mockConnection);
        const metaXMLString = 'Incorrect metadata file';
        chai_1.assert.throws(() => deployLibrary.buildMetadataField(metaXMLString), i18n_1.nls.localize('error_parsing_metadata_file'));
    });
});
//# sourceMappingURL=baseDeploy.test.js.map