"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
const keanuConstants_1 = require("../../mock/registry/keanuConstants");
const registry_1 = require("../../mock/registry");
const chai_1 = require("chai");
const defaultMetadataTransformer_1 = require("../../../src/convert/transformers/defaultMetadataTransformer");
const transformers_1 = require("../../../src/convert/transformers");
const decomposedMetadataTransformer_1 = require("../../../src/convert/transformers/decomposedMetadataTransformer");
const reginaConstants_1 = require("../../mock/registry/reginaConstants");
const convertTransaction_1 = require("../../../src/convert/convertTransaction");
const mixedContentSingleFileConstants_1 = require("../../mock/registry/mixedContentSingleFileConstants");
const staticResourceMetadataTransformer_1 = require("../../../src/convert/transformers/staticResourceMetadataTransformer");
describe('MetadataTransformerFactory', () => {
    it('should return DefaultMetadataTransformer', () => {
        const component = keanuConstants_1.KEANU_COMPONENT;
        const factory = new transformers_1.MetadataTransformerFactory(registry_1.mockRegistry);
        chai_1.expect(factory.getTransformer(component)).to.deep.equal(new defaultMetadataTransformer_1.DefaultMetadataTransformer(registry_1.mockRegistry));
    });
    it('should return DecomposedMetadataTransformer', () => {
        const component = reginaConstants_1.REGINA_COMPONENT;
        const transaction = new convertTransaction_1.ConvertTransaction();
        const factory = new transformers_1.MetadataTransformerFactory(registry_1.mockRegistry, transaction);
        chai_1.expect(factory.getTransformer(component)).to.deep.equal(new decomposedMetadataTransformer_1.DecomposedMetadataTransformer(registry_1.mockRegistry, transaction));
    });
    it('should return StaticResourceMetadataTransformer', () => {
        const component = mixedContentSingleFileConstants_1.MC_SINGLE_FILE_COMPONENT;
        const factory = new transformers_1.MetadataTransformerFactory(registry_1.mockRegistry);
        chai_1.expect(factory.getTransformer(component)).to.deep.equal(new staticResourceMetadataTransformer_1.StaticResourceMetadataTransformer(registry_1.mockRegistry));
    });
});
//# sourceMappingURL=metadataTransformerFactory.test.js.map