"use strict";
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const i18n_1 = require("../../src/i18n");
const i18n = require("./i18n");
/**
 * This snippet of code needs to be copied/generated to all localization points.
 */
function loadMessageBundle() {
    return new i18n_1.Message(i18n.messages);
}
describe('Localization tests', () => {
    it('Should handle default locale', () => {
        const nls = new i18n_1.Localization(loadMessageBundle());
        chai_1.expect(nls.localize('key_1')).to.be.equals('Hello');
    });
    it('Should not fail if a key is missing in default locale', () => {
        const nls = new i18n_1.Localization(loadMessageBundle());
        chai_1.expect(nls.localize('non_existent_key')).to.be.equals('!!! MISSING LABEL !!! non_existent_key');
    });
    it('Should not error if arg counts do no match', () => {
        const nls = new i18n_1.Localization(loadMessageBundle());
        chai_1.expect(() => nls.localize('key_3')).to.not.throw();
    });
    it('Should perform substitution in default locale if args >=1', () => {
        const nls = new i18n_1.Localization(loadMessageBundle());
        chai_1.expect(nls.localize('key_3_with_args', 'John')).to.be.equals('Hello John');
    });
    it('Should perform substitution in default locale if args >=1 with an array', () => {
        const nls = new i18n_1.Localization(loadMessageBundle());
        chai_1.expect(nls.localize('key_3_with_args', ['John'])).to.be.equals('Hello John');
    });
    it('Should append args for missing label', () => {
        const nls = new i18n_1.Localization(loadMessageBundle());
        chai_1.expect(nls.localize('non_existent_key', 'John')).to.be.equals('!!! MISSING LABEL !!! non_existent_key (John)');
    });
});
//# sourceMappingURL=localization.test.js.map