"use strict";
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
const registry_1 = require("../../mock/registry");
const chai_1 = require("chai");
const bundleSourceAdapter_1 = require("../../../src/metadata-registry/adapters/bundleSourceAdapter");
const path_1 = require("path");
const treeContainers_1 = require("../../../src/metadata-registry/treeContainers");
const simonConstants_1 = require("../../mock/registry/simonConstants");
const metadata_registry_1 = require("../../../src/metadata-registry");
describe('BundleSourceAdapter', () => {
    const { SIMON_BUNDLE_PATH, SIMON_XML_PATH, SIMON_SOURCE_PATHS, SIMON_DIR, SIMON_COMPONENT, } = registry_1.simon;
    const type = registry_1.mockRegistry.types.simonpegg;
    const tree = new treeContainers_1.VirtualTreeContainer([
        {
            dirPath: SIMON_DIR,
            children: [path_1.basename(SIMON_BUNDLE_PATH)],
        },
        {
            dirPath: SIMON_BUNDLE_PATH,
            children: [simonConstants_1.SIMON_XML_NAME, ...SIMON_SOURCE_PATHS.map((p) => path_1.basename(p))],
        },
    ]);
    const adapter = new bundleSourceAdapter_1.BundleSourceAdapter(type, registry_1.mockRegistry, undefined, tree);
    const expectedComponent = new metadata_registry_1.SourceComponent(SIMON_COMPONENT, tree);
    it('Should return expected SourceComponent when given a root metadata xml path', () => {
        chai_1.expect(adapter.getComponent(SIMON_XML_PATH)).to.deep.equal(expectedComponent);
    });
    it('Should return expected SourceComponent when given a source path', () => {
        const randomSource = SIMON_SOURCE_PATHS[Math.floor(Math.random() * Math.floor(SIMON_SOURCE_PATHS.length))];
        chai_1.expect(adapter.getComponent(randomSource)).to.deep.equal(expectedComponent);
    });
});
//# sourceMappingURL=bundleSourceAdapter.js.map